aboutsummaryrefslogtreecommitdiffstats
path: root/lib/Fripost/Schema/Local.pm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Fripost/Schema/Local.pm')
-rw-r--r--lib/Fripost/Schema/Local.pm14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/Fripost/Schema/Local.pm b/lib/Fripost/Schema/Local.pm
index 49c3d68..400b4e5 100644
--- a/lib/Fripost/Schema/Local.pm
+++ b/lib/Fripost/Schema/Local.pm
@@ -7,7 +7,7 @@ Local.pm -
=head1 DESCRIPTION
Local.pm abstracts the LDAP schema definition and provides methods to
-search for virtual mailboxes, aliases or lists alltogether.
+search for virtual users, aliases or lists alltogether.
=cut
@@ -29,7 +29,7 @@ use Net::IDN::Encode qw/email_to_ascii email_to_unicode/;
Returns a hash with all the (visible) attributes for the given entry. An
additional 'type' attribute gives the type of *the* found entry
-(possible values are 'mailbox', 'alias', and 'list').
+(possible values are 'user', 'alias', and 'list').
=cut
@@ -44,14 +44,14 @@ sub get {
base => "fvd=$d,".$self->suffix,
scope => 'one',
deref => 'never',
- filter => "(|(&(objectClass=FripostVirtualMailbox)(fvu=$l))
+ filter => "(|(&(objectClass=FripostVirtualUser)(fvu=$l))
(&(objectClass=FripostVirtualAlias)(fva=$l))
(&(objectClass=FripostVirtualList)(fvl=$l)))",
attrs => [ qw/fvu description
fripostIsStatusActive
fripostIsStatusPending
fripostOptionalMaildrop
- fripostMailboxQuota
+ fripostUserQuota
fva fripostMaildrop
fvl fripostListManager/ ]
);
@@ -62,7 +62,7 @@ sub get {
# The following is not supposed to happen. Note that there is
# nothing in the LDAP schema to prevent that, but it's not too
# critical as Postfix search for mailboxes, aliases and lists in
# that order.
die "Error: Multiple matching entries found." if $locals->count > 1;
my $local = $locals->pop_entry;
@@ -74,7 +74,7 @@ sub get {
my %ret;
if ($local->dn =~ /^fvu=/) {
- $ret{type} = 'mailbox';
+ $ret{type} = 'user';
$ret{user} = $local->get_value('fvu');
$ret{forwards} = concat($concat, map { email_to_unicode($_) }
$local->get_value('fripostOptionalMaildrop'))
@@ -113,7 +113,7 @@ sub exists {
# We may not have read access to the list commands
# The trick is somewhat dirty, but it's safe enough since postfix
# delivers to mailboxes, aliases, and lists with different
# priorities (and lists have the lowest).
my @cmds = qw/admin bounces confirm join leave owner request subscribe unsubscribe bounce sendkey/;
my @tests = ( 'fvu='.$l, 'fva='.$l, 'fvl='.$l );
@@ -62,7 +62,7 @@ sub get {
# The following is not supposed to happen. Note that there is
# nothing in the LDAP schema to prevent that, but it's not too
- # critical as Postfix search for mailboxes, aliases and lists in
+ # critical as Postfix searchs for user, aliases and lists in
# that order.
die "Error: Multiple matching entries found." if $locals->count > 1;
@@ -113,7 +113,7 @@ sub exists {
# We may not have read access to the list commands
# The trick is somewhat dirty, but it's safe enough since postfix
- # delivers to mailboxes, aliases, and lists with different
+ # delivers to users, aliases, and lists with different
# priorities (and lists have the lowest).
my @cmds = qw/admin bounces confirm join leave owner request subscribe unsubscribe bounce sendkey/;